@@ -9,12 +9,6 @@ from simple_tensor.networks.inception_utils import *
 from simple_tensor.networks.inception_v4 import *
 from simple_tensor.networks.resnet_v2 import *
 import simple_tensor.networks.densenet as densenet
-from comdutils.file_utils import *
-
-from sklearn.metrics import accuracy_score
-from sklearn.metrics import recall_score
-from sklearn.metrics import precision_score
-
 
 
 class ImageRecognition(object):
@@ -126,7 +120,7 @@ class ImageRecognition(object):
             # get inception variable name
             base_var_list = tf.get_collection(tf.GraphKeys.GLOBAL_VARIABLES)
 
-        with tf.variable_scope('inceptionV4'):
+        with tf.variable_scope('InceptionV4'):
             size = out.get_shape().as_list()[1]
             while(True):
                 if size == 1:
@@ -238,7 +232,8 @@ class ImageRecognition(object):
             image_name_list {list of string} -- the list of image name
         """
         import cv2 
-        
+        from comdutils.file_utils import get_filenames
+
         file_list = get_filenames(os.path.join(dataset_path, self.classes[0]))
         self.file_num = len(file_list) * len(self.classes)
         self.tmp_batch_size = batch_size
@@ -312,6 +307,10 @@ class ImageRecognition(object):
                         session, 
                         cost_tensor,
                         out_tensor): 
+        from sklearn.metrics import accuracy_score
+        from sklearn.metrics import recall_score
+        from sklearn.metrics import precision_score
+
         x_val, y_val = next(val_generator)
         iteration_needed = math.ceil(self.file_num / self.tmp_batch_size)
 
@@ -372,6 +371,7 @@ class ImageRecognition(object):
             val_batch_size {int} -- [description] (default: {50})
             path_tosave_model {str} -- [description] (default: {'model/model1'})
         """
+        from sklearn.metrics import accuracy_score
 
         self.train_loss = []
         self.val_loss = []
